@@ -103,7 +103,7 @@ class PartitionAPI(API):
         createRequest = CreatePartitionRequest(name=name, external_id=external_id)
         return Partition.from_proto(self.query.CreatePartition(createRequest, metadata=self.metadata))
 
-    def edit(self, *, id: Optional[int] = None, external_id: MaybeString = None, new_name: str) -> Partition:
+    def edit(self, *, new_name: str, id: Optional[int] = None, external_id: MaybeString = None) -> Partition:
         """Edit an existing partition.
 
         Edit an existing partition by providing either an id or an external id.
