@@ -44,9 +44,9 @@ class SeismicAPI(API):
         self,
         *,
         external_id: str,
-        name: MaybeString = None,
         partition_identifier: Union[int, str],
         seismic_store_id: int,
+        name: MaybeString = None,
         volumedef: Optional[str] = None,
         geometry: Optional[Geometry] = None,
         metadata: Optional[Metadata] = None,
@@ -178,7 +178,8 @@ For example, search(coverage_format="wkt") is identical to using include_coverag
         req.include_partition = include_partition
 
         results = self.query.SearchSeismics(req, metadata=self.metadata)
-        return [Seismic.from_proto(s) for s in results]
+        for s in results:
+            yield Seismic.from_proto(s)
 
     def list(
         self,
