@@ -62,7 +62,9 @@ class SurveyV1API(API):
     def search(
         self,
         name_substring: Optional[str] = None,
+        survey_name_substring: Optional[str] = None,
         external_id_substring: Optional[str] = None,
+        survey_external_id_substring: Optional[str] = None,
         list_seismics: bool = False,
         list_seismic_stores: bool = False,
         include_metadata: bool = False,
@@ -88,6 +90,11 @@ class SurveyV1API(API):
         Returns:
             List[Survey]: the requested surveys and their files (if requested).
         """
+        if name_substring is None:
+            name_substring = survey_name_substring
+        if external_id_substring is None:
+            external_id_substring = survey_external_id_substring
+
         if name_substring is None and external_id_substring is None:
             raise Exception("either survey_name_substring or survey_external_id_substring must be specified")
 
@@ -111,8 +118,11 @@ class SurveyV1API(API):
     def get(
         self,
         id: Optional[str] = None,
+        survey_id: Optional[str] = None,
         external_id: Optional[str] = None,
+        survey_external_id: Optional[str] = None,
         name: Optional[str] = None,
+        survey_name: Optional[str] = None,
         list_seismics: bool = False,
         list_seismic_stores: bool = False,
         include_metadata: bool = False,
@@ -140,6 +150,13 @@ class SurveyV1API(API):
         Returns:
             Survey: the requested survey, its seismics, seismic stores and metadata (if requested).
         """
+        if id is None:
+            id = survey_id
+        if external_id is None:
+            external_id = survey_external_id
+        if name is None:
+            name = survey_name
+
         search_spec = None
         if id is None and external_id is None and name is None:
             raise Exception("Must specify either survey_id, survey_name or survey_external_id.")
@@ -169,6 +186,7 @@ class SurveyV1API(API):
     def register(
         self,
         name: str,
+        survey_name: str,
         metadata: dict = None,
         external_id: Optional[str] = None,
         crs: Optional[str] = None,
@@ -200,6 +218,9 @@ class SurveyV1API(API):
         Returns:
             RegisterSurveyResponse: id, name and metadata of the survey.
         """
+        if name is None:
+            name = survey_name
+
         return self.v0_survey_api.register(
             name, metadata, external_id, crs, grid_transformation, custom_coverage_wkt, custom_coverage_geojson
         )
@@ -207,9 +228,12 @@ class SurveyV1API(API):
     def edit(
         self,
         id: Optional[str] = None,
+        survey_id: Optional[str] = None,
         name: Optional[str] = None,
+        survey_name: Optional[str] = None,
         metadata: dict = None,
         external_id: Optional[str] = None,
+        survey_external_id: Optional[str] = None,
         crs: Optional[str] = None,
         grid_transformation: Optional[SurveyGridTransformation] = None,
         custom_coverage_wkt: Optional[str] = None,
@@ -244,6 +268,12 @@ class SurveyV1API(API):
             EditSurveyResponse: id, name and metadata of the survey.
 
         """
+        if id is None:
+            id = survey_id
+        if name is None:
+            name = survey_name
+        if external_id is None:
+            external_id = survey_external_id
         return self.v0_survey_api.edit(
             id,
             name,
@@ -256,7 +286,13 @@ class SurveyV1API(API):
             clear_custom_coverage,
         )
 
-    def delete(self, id: Optional[str] = None, name: Optional[str] = None):
+    def delete(
+        self,
+        id: Optional[str] = None,
+        survey_id: Optional[str] = None,
+        name: Optional[str] = None,
+        survey_name: Optional[str] = None,
+    ):
         """Delete a survey
 
         Args:
@@ -267,6 +303,10 @@ class SurveyV1API(API):
             Nothing
 
         """
+        if id is None:
+            id = survey_id
+        if name is None:
+            name = survey_name
         return self.v0_survey_api.delete(id, name)
 
     def _search_internal(
