@@ -136,7 +136,17 @@ class CogniteSeismicClient:
     Main class for the seismic client
     """
 
-    def __init__(self, api_key=None, base_url=None, port=None, custom_root_cert=None, *, insecure=False, project=None):
+    def __init__(
+        self,
+        api_key=None,
+        base_url=None,
+        port=None,
+        custom_root_cert=None,
+        *,
+        insecure=False,
+        project=None,
+        no_retries=False,
+    ):
         # configure env
         self.api_key = api_key or os.getenv("COGNITE_API_KEY")
         self.project = project or os.getenv("COGNITE_PROJECT")
@@ -183,7 +193,8 @@ class CogniteSeismicClient:
         self.ingestion = ingest_serv.IngestStub(channel)
         self.seismicstub = seismic_serv.SeismicAPIStub(channel)
 
-        decorate_with_retries(self.query, self.ingestion, self.seismicstub)
+        if not no_retries:
+            decorate_with_retries(self.query, self.ingestion, self.seismicstub)
         decorate_with_wrapped_rpc_errors(self.query, self.ingestion, self.seismicstub)
 
         self.survey = SurveyAPI(self.query, self.ingestion, self.metadata)
@@ -197,6 +208,10 @@ class CogniteSeismicClient:
         self.survey_v1 = SurveyV1API(self.seismicstub, self.metadata, self.survey)
         self.volume_seismic = VolumeSeismicAPI(self.seismicstub, self.ingestion, self.metadata)
         self.partition = PartitionAPI(self.seismicstub, self.ingestion, self.metadata)
+        # The duplicated seismic/seismics is for making the rename backwards compatible.
+        # The singular form is the one that we expect to keep after a breaking release.
         self.seismic = SeismicAPI(self.seismicstub, self.ingestion, self.metadata)
+        self.seismics = SeismicAPI(self.seismicstub, self.ingestion, self.metadata)
         self.seismicstore = SeismicStoreAPI(self.seismicstub, self.ingestion, self.metadata)
+        self.seismicstores = SeismicStoreAPI(self.seismicstub, self.ingestion, self.metadata)
         self.file_seismic = FileSeismicAPI(self.seismicstub, self.ingestion, self.metadata, self)
