@@ -1141,9 +1141,20 @@ class Survey:
     coverage: Optional[Geometry]
     crs: Optional[str]
     grid_transformation: Optional[SurveyGridTransformation]
+    custom_coverage: Optional[Geometry]
 
     def __init__(
-        self, id, external_id, name, seismic_ids, seismic_store_ids, metadata, coverage, crs, grid_transformation
+        self,
+        id,
+        external_id,
+        name,
+        seismic_ids,
+        seismic_store_ids,
+        metadata,
+        coverage,
+        crs,
+        grid_transformation,
+        custom_coverage,
     ):
         self.id = id
         self.external_id = external_id
@@ -1154,11 +1165,12 @@ class Survey:
         self.coverage = coverage
         self.crs = crs
         self.grid_transformation = grid_transformation
+        self.custom_coverage = custom_coverage
 
     @staticmethod
     def from_proto(proto) -> "Survey":
         survey_id = proto.survey.id
-        external_id = proto.survey.external_id if hasattr(proto.survey, "external_id") else None
+        external_id = proto.survey.external_id.external_id if hasattr(proto.survey, "external_id") else None
         name = proto.survey.name if hasattr(proto.survey, "name") else None
         metadata = proto.survey.metadata if hasattr(proto.survey, "metadata") else None
         seismic_ids = proto.seismic_ids if hasattr(proto, "seismic_ids") else None
@@ -1170,8 +1182,22 @@ class Survey:
             if proto.survey.HasField("grid_transformation")
             else None
         )
+        if proto.survey.HasField("custom_coverage") and proto.survey.custom_coverage.HasField("custom_coverage"):
+            custom_coverage = Geometry.from_proto(proto.survey.custom_coverage.custom_coverage)
+        else:
+            custom_coverage = None
+
         return Survey(
-            survey_id, external_id, name, seismic_ids, seismic_store_ids, metadata, coverage, crs, grid_transformation
+            survey_id,
+            external_id,
+            name,
+            seismic_ids,
+            seismic_store_ids,
+            metadata,
+            coverage,
+            crs,
+            grid_transformation,
+            custom_coverage,
         )
 
     def __repr__(self):
